@@ -21,7 +21,14 @@ from .datastructure import (
     validate_tuple,
 )
 
-from .email import validate_email_address
+from .uuid import validate_uuid
+
+try:
+    from .email import validate_email_address
+except ImportError:
+    # `validate_email_address` is only available if the `idna` package is
+    # installed.  Depend on `validation[email]` to pull in the right version.
+    pass
 
 __all__ = [
     'validate_int', 'validate_float', 'validate_bool',
@@ -29,6 +36,6 @@ __all__ = [
     'validate_date', 'validate_datetime',
     'validate_list', 'validate_set',
     'validate_mapping', 'validate_structure',
-    'validate_tuple',
+    'validate_tuple', 'validate_uuid',
     'validate_email_address',
 ]
